## Introduction

MOMIA (or Mycobacteria Optimized Microscopy Image Analysis) is a python based image analysis toolkit optimized for dealing with mycobacterial cells. Given a single or a set of fluorescent microscopic image(s), OMEGA renders accurate object segmentation and graphical representation of fluroescent or morphological profiles at both the single cell level and the populational level. OMEGA was developed to analyze a *M. smegmatis* fluorsecent protein tagging library (Mycobacterial Systems Resource, Dendra, or MSR-Dendra) which accounts for over 1,000 highly conserved mycobacterial genes. You may find the MSR-Dendra dataset (along with many other amazing mycobacterial resources) on this [website](http://msrdb.org/). 

## MOMIA is still under development, please use with caution. ##

## Installation

To install MOMIA from the Python Package index (PyPi) , make sure you have
[pip installed](https://pip.readthedocs.io/en/stable/installing/), then run:

    $ pip install momia
